@@ -110,7 +110,7 @@ grid_terrain.LAS = function(las, res = 1, algorithm, keep_lowest = FALSE)
   hull <- sp::SpatialPolygons(list(sp::Polygons(list(hull), "null")))
   hull <- rgeos::gBuffer(hull, width = raster::res(layout)[1])
   hull <- hull@polygons[[1]]@Polygons[[1]]@coords
-  keep <- C_points_in_polygon(hull[,1], hull[,2], grid$X, grid$Y)
+  keep <- sp::point.in.polygon(grid$X, grid$Y, hull[,1], hull[,2], TRUE) > 0
   if (!all(keep)) grid = grid[keep]
 
   # Interpolate the terrain
