@@ -107,7 +107,7 @@ test_that("LAS throws a warning/error if building an invalid LAS", {
   header@PHB$`Point Data Format ID` <- 3L
   header@PHB$`X scale factor` <- 0.412
 
-  expect_error(LAS(data, header), "X scale factor")
+  expect_warning(LAS(data, header), "X scale factor")
 
   # Invalid RGB
 
