@@ -4,7 +4,7 @@ las <- lidR:::dummy_las(5000)
 projection(las) <- sp::CRS("+init=epsg:4326")
 las@data[, Z := Z + 0.1*X + 0.1*Y + sin(0.01*X) - sin(0.1*Y) + sin(0.003*X*Y)]
 
-tdtm   <- lidR:::make_overlay_raster(las, 1)
+tdtm   <- lidR:::rOverlay(las, 1)
 xy     <- raster::xyFromCell(tdtm, 1:raster::ncell(tdtm))
 X      <- xy[,1]
 Y      <- xy[,2]
